==> identity-editor-1.1.8-sources.jar: io/intino/amidas/identityeditor/box/ui/displays/templates/AbstractPropertyEditor.java <==
package io.intino.amidas.identityeditor.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.amidas.identityeditor.box.ui.*;

import io.intino.amidas.identityeditor.box.IdentityEditorBox;

import io.intino.amidas.identityeditor.box.ui.displays.templates.*;



import io.intino.amidas.identityeditor.box.ui.displays.notifiers.PropertyEditorNotifier;

public abstract class AbstractPropertyEditor<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<PropertyEditorNotifier, java.lang.Void, B> {
	public Identity_27_1_0799723893 Identity_27_1_0799723893;
	public PropertyEditor.Identity_27_1_0799723893. Property property;
	public StringType stringType;
	public PropertyEditor.StringType. StringValue stringValue;
	public PropertyEditor.StringType. StringGrammarBlock stringGrammarBlock;
	public PropertyEditor.StringType.StringGrammarBlock. StringGrammarLabel stringGrammarLabel;
	public PropertyEditor.StringType.StringGrammarBlock. StringGrammar stringGrammar;
	public PropertyEditor.StringType. StringInvalidBlock stringInvalidBlock;
	public PropertyEditor.StringType.StringInvalidBlock. StringInvalidValue stringInvalidValue;
	public ImageType imageType;
	public PropertyEditor.ImageType. ImageValue imageValue;

    public AbstractPropertyEditor(B box) {
        super(box);
        id("propertyEditor");
    }

    @Override
	public void init() {
		super.init();
		if (Identity_27_1_0799723893 == null) Identity_27_1_0799723893 = register(new Identity_27_1_0799723893(box()).<Identity_27_1_0799723893>id("a_1407481946").owner(AbstractPropertyEditor.this));
		if (Identity_27_1_0799723893 != null) property = Identity_27_1_0799723893.property;
		if (stringType == null) stringType = register(new StringType(box()).<StringType>id("a_984158167").owner(AbstractPropertyEditor.this));
		if (stringType != null) stringValue = stringType.stringValue;
		if (stringType != null) stringGrammarBlock = stringType.stringGrammarBlock;
		if (stringGrammarBlock != null) stringGrammarLabel = stringType.stringGrammarBlock.stringGrammarLabel;
		if (stringGrammarBlock != null) stringGrammar = stringType.stringGrammarBlock.stringGrammar;
		if (stringType != null) stringInvalidBlock = stringType.stringInvalidBlock;
		if (stringInvalidBlock != null) stringInvalidValue = stringType.stringInvalidBlock.stringInvalidValue;
		if (imageType == null) imageType = register(new ImageType(box()).<ImageType>id("a249227831").owner(AbstractPropertyEditor.this));
		if (imageType != null) imageValue = imageType.imageValue;
	}

	public class Identity_27_1_0799723893 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public PropertyEditor.Identity_27_1_0799723893. Property property;

		public Identity_27_1_0799723893(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (property == null) property = register(new Property(box()).<Property>id("a_1145724228").owner(AbstractPropertyEditor.this));
		}

		public class Property extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Property(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}

	public class StringType extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public PropertyEditor.StringType. StringValue stringValue;
		public PropertyEditor.StringType. StringGrammarBlock stringGrammarBlock;
		public PropertyEditor.StringType. StringInvalidBlock stringInvalidBlock;

		public StringType(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (stringValue == null) stringValue = register(new StringValue(box()).<StringValue>id("a_37094198").owner(AbstractPropertyEditor.this));
			if (stringGrammarBlock == null) stringGrammarBlock = register(new StringGrammarBlock(box()).<StringGrammarBlock>id("a_1659966547").owner(AbstractPropertyEditor.this));
			if (stringInvalidBlock == null) stringInvalidBlock = register(new StringInvalidBlock(box()).<StringInvalidBlock>id("a_1759685795").owner(AbstractPropertyEditor.this));
		}

		public class StringValue extends io.intino.alexandria.ui.displays.components.TextEditable<io.intino.alexandria.ui.displays.notifiers.TextEditableNotifier, B>  {

			public StringValue(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class StringGrammarBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public PropertyEditor.StringType.StringGrammarBlock. StringGrammarLabel stringGrammarLabel;
			public PropertyEditor.StringType.StringGrammarBlock. StringGrammar stringGrammar;

			public StringGrammarBlock(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (stringGrammarLabel == null) stringGrammarLabel = register(new StringGrammarLabel(box()).<StringGrammarLabel>id("a_1054780400").owner(AbstractPropertyEditor.this));
				if (stringGrammar == null) stringGrammar = register(new StringGrammar(box()).<StringGrammar>id("a_1209277116").owner(AbstractPropertyEditor.this));
			}

			public class StringGrammarLabel extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public StringGrammarLabel(B box) {
					super(box);
					_value("options: ");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class StringGrammar extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public StringGrammar(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class StringInvalidBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public PropertyEditor.StringType.StringInvalidBlock. StringInvalidValue stringInvalidValue;

			public StringInvalidBlock(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (stringInvalidValue == null) stringInvalidValue = register(new StringInvalidValue(box()).<StringInvalidValue>id("a_1754109811").owner(AbstractPropertyEditor.this));
			}

			public class StringInvalidValue extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public StringInvalidValue(B box) {
					super(box);
					_value("Value is not valid");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}

	public class ImageType extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public PropertyEditor.ImageType. ImageValue imageValue;

		public ImageType(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (imageValue == null) imageValue = register(new ImageValue(box()).<ImageValue>id("a_141472802").owner(AbstractPropertyEditor.this));
		}

		public class ImageValue extends io.intino.alexandria.ui.displays.components.ImageEditable<io.intino.alexandria.ui.displays.notifiers.ImageEditableNotifier, B>  {

			public ImageValue(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> identity-editor-2.0.2-sources.jar: io/intino/amidas/identityeditor/box/ui/displays/templates/AbstractPropertyEditor.java <==
package io.intino.amidas.identityeditor.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.amidas.identityeditor.box.ui.*;

import io.intino.amidas.identityeditor.box.IdentityEditorBox;

import io.intino.amidas.identityeditor.box.ui.displays.templates.*;








import io.intino.amidas.identityeditor.box.ui.displays.notifiers.PropertyEditorNotifier;

public abstract class AbstractPropertyEditor<DN extends PropertyEditorNotifier, B extends Box> extends io.intino.alexandria.ui.displays.components.Template<DN, java.lang.Void, B> {
	public _27_1_0799723893 _27_1_0799723893;
	public PropertyEditor._27_1_0799723893. Property property;
	public StringType stringType;
	public PropertyEditor.StringType. StringValue stringValue;
	public PropertyEditor.StringType. StringGrammarBlock stringGrammarBlock;
	public PropertyEditor.StringType.StringGrammarBlock. StringGrammarLabel stringGrammarLabel;
	public PropertyEditor.StringType.StringGrammarBlock. StringGrammar stringGrammar;
	public PropertyEditor.StringType. StringInvalidBlock stringInvalidBlock;
	public PropertyEditor.StringType.StringInvalidBlock. StringInvalidValue stringInvalidValue;
	public ImageType imageType;
	public PropertyEditor.ImageType. ImageValue imageValue;

	public AbstractPropertyEditor(B box) {
		super(box);
		id("propertyEditor");
	}

	@Override
	public void init() {
		super.init();
		if (_27_1_0799723893 == null) _27_1_0799723893 = register(new _27_1_0799723893(box()).<_27_1_0799723893>id("a_77738808").owner(AbstractPropertyEditor.this));
		if (_27_1_0799723893 != null) property = _27_1_0799723893.property;
		if (stringType == null) stringType = register(new StringType(box()).<StringType>id("a_984158167").owner(AbstractPropertyEditor.this));
		if (stringType != null) stringValue = stringType.stringValue;
		if (stringType != null) stringGrammarBlock = stringType.stringGrammarBlock;
		if (stringGrammarBlock != null) stringGrammarLabel = stringType.stringGrammarBlock.stringGrammarLabel;
		if (stringGrammarBlock != null) stringGrammar = stringType.stringGrammarBlock.stringGrammar;
		if (stringType != null) stringInvalidBlock = stringType.stringInvalidBlock;
		if (stringInvalidBlock != null) stringInvalidValue = stringType.stringInvalidBlock.stringInvalidValue;
		if (imageType == null) imageType = register(new ImageType(box()).<ImageType>id("a249227831").owner(AbstractPropertyEditor.this));
		if (imageType != null) imageValue = imageType.imageValue;
	}

	@Override
	public void remove() {
		super.remove();
		if (_27_1_0799723893 != null) _27_1_0799723893.unregister();
		if (stringType != null) stringType.unregister();
		if (imageType != null) imageType.unregister();
	}

	public class _27_1_0799723893 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public PropertyEditor._27_1_0799723893. Property property;

		public _27_1_0799723893(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (property == null) property = register(new Property(box()).<Property>id("a_1145724228").owner(AbstractPropertyEditor.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (property != null) property.unregister();
		}

		public class Property extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Property(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}

	public class StringType extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public PropertyEditor.StringType. StringValue stringValue;
		public PropertyEditor.StringType. StringGrammarBlock stringGrammarBlock;
		public PropertyEditor.StringType. StringInvalidBlock stringInvalidBlock;

		public StringType(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (stringValue == null) stringValue = register(new StringValue(box()).<StringValue>id("a_37094198").owner(AbstractPropertyEditor.this));
			if (stringGrammarBlock == null) stringGrammarBlock = register(new StringGrammarBlock(box()).<StringGrammarBlock>id("a_1659966547").owner(AbstractPropertyEditor.this));
			if (stringInvalidBlock == null) stringInvalidBlock = register(new StringInvalidBlock(box()).<StringInvalidBlock>id("a_1759685795").owner(AbstractPropertyEditor.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (stringValue != null) stringValue.unregister();
			if (stringGrammarBlock != null) stringGrammarBlock.unregister();
			if (stringInvalidBlock != null) stringInvalidBlock.unregister();
		}

		public class StringValue extends io.intino.alexandria.ui.displays.components.TextEditable<io.intino.alexandria.ui.displays.notifiers.TextEditableNotifier, B>  {

			public StringValue(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}

		public class StringGrammarBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public PropertyEditor.StringType.StringGrammarBlock. StringGrammarLabel stringGrammarLabel;
			public PropertyEditor.StringType.StringGrammarBlock. StringGrammar stringGrammar;

			public StringGrammarBlock(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (stringGrammarLabel == null) stringGrammarLabel = register(new StringGrammarLabel(box()).<StringGrammarLabel>id("a_1054780400").owner(AbstractPropertyEditor.this));
				if (stringGrammar == null) stringGrammar = register(new StringGrammar(box()).<StringGrammar>id("a_1209277116").owner(AbstractPropertyEditor.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (stringGrammarLabel != null) stringGrammarLabel.unregister();
				if (stringGrammar != null) stringGrammar.unregister();
			}

			public class StringGrammarLabel extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public StringGrammarLabel(B box) {
					super(box);
					_value("options: ");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}

			public class StringGrammar extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public StringGrammar(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}
		}

		public class StringInvalidBlock extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public PropertyEditor.StringType.StringInvalidBlock. StringInvalidValue stringInvalidValue;

			public StringInvalidBlock(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (stringInvalidValue == null) stringInvalidValue = register(new StringInvalidValue(box()).<StringInvalidValue>id("a_1754109811").owner(AbstractPropertyEditor.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (stringInvalidValue != null) stringInvalidValue.unregister();
			}

			public class StringInvalidValue extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public StringInvalidValue(B box) {
					super(box);
					_value("Value is not valid");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}
		}
	}

	public class ImageType extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public PropertyEditor.ImageType. ImageValue imageValue;

		public ImageType(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (imageValue == null) imageValue = register(new ImageValue(box()).<ImageValue>id("a_141472802").owner(AbstractPropertyEditor.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (imageValue != null) imageValue.unregister();
		}

		public class ImageValue extends io.intino.alexandria.ui.displays.components.ImageEditable<io.intino.alexandria.ui.displays.notifiers.ImageEditableNotifier, B>  {

			public ImageValue(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}
}
